/**
 * LeftPanel.java
 *
 * This panel is used by the MainPanel class for displaying the left window
 * with the three buttons for listing, creating new record and cancel or
 * help. 
 * 
 * @author xjqiu@npac.syr.edu
 */

import java.awt.*;
import java.awt.event.*;

public class LeftPanel extends Panel { // class definition

 GridBagLayout gb = new GridBagLayout();  // define layout for this panel
 GridBagConstraints gbc = new GridBagConstraints(); // constraints for the panel

 private Button b0,b1,b2,b3,b4; // declare buttons
 private Label  head = new Label("Option Frame"); // declare the title
 private Color bg = new Color(0,80,80); //background color
 private Color fg = new Color(255,255,255); //foreground color

/**
 * Constructor for the class takes in an ActionListener argument so that
 * when a button is clicked the appropriate action is taken. The
 * constructor builds up the panel and places and buttons and set the
 * fonts and background and foreground colors etc on the panel.
 */

 public LeftPanel(ActionListener caller) { 

	 Color buttonbg = new Color(71,57,0);
	 Color buttonfg = new Color(255,255,255);

     setLayout(gb);  // set the gridbaglayout
     setBackground(bg); //set background color for the panel
     setForeground(fg); // set foreground color
     setSize(300,300); // set size for the panel
   
     gbc.fill = GridBagConstraints.NONE; // set the fill as none
     gbc.anchor = GridBagConstraints.NORTHWEST; // sets anchor as NORTHWEST

     setFont(new Font("Helvetica", Font.BOLD, 15)); // sets font
     head.setForeground(new Color(222,184,87)); //set foreground for the title
     addComp(head,0,0,1,1,new Insets(-185,20,1,0)); //add the title 

     setFont(new Font("Helvetica", Font.BOLD, 12)); // sets font

     b0 = new Button("     Open     "); // add the list button
     b0.setForeground(buttonfg);
	 b0.setBackground(buttonbg);
     b0.addActionListener(caller); // add the listener for this button
     addComp(b0,2,2,1,1,new Insets(-145,-75,1,35));


     b1 = new Button("  Search "); // add the list button
     b1.setForeground(buttonfg);
	 b1.setBackground(buttonbg);
     b1.addActionListener(caller); // add the listener for this button
     addComp(b1,2,4,1,1,new Insets(-115,-75,1,35));

	 b2 = new Button("   Insert  "); //add the new button and listener for this button
     b2.setForeground(buttonfg);
	 b2.setBackground(buttonbg);
	 b2.addActionListener(caller);
     addComp(b2,2,6,1,1,new Insets(-85,-75,1,35));


	 b4 = new Button("     Close    "); //add the cancel button and its listener
     b4.setForeground(buttonfg);
	 b4.setBackground(buttonbg);
	 b4.addActionListener(caller);
     addComp(b4,2,10,1,1,new Insets(-55,-75,1,35));

	 b3 = new Button("     Guide    "); //add the cancel button and its listener
     b3.setForeground(buttonfg);
	 b3.setBackground(buttonbg);
	 b3.addActionListener(caller);
     addComp(b3,2,8,1,1,new Insets(-25,-75,1,35));
 }

 /**
 * Method that actually sets the parameters and adds the component
 * to the panel. Gets the coordinates, width and height and insets
 * as well as the component object as arguments.
 */

 private void addComp
            ( Component c, int x, int y, int ht, int wt, Insets insets ) {
     gbc.gridx = x;
     gbc.gridy = y;

     gbc.gridwidth = wt;
     gbc.gridheight = ht;

     gbc.insets = insets;

     gb.setConstraints(c,gbc);
     add(c);
 }
} //end of class
